@@ -10,16 +10,23 @@
 # Contact: ops@keepersecurity.com
 #
 
-import pexpect
-from pexpect import pxssh
+import logging
+import os
+from ...error import Error
+
+if os.name == 'posix':
+    from pexpect import pxssh, exceptions
+else:
+    raise Exception('Not available on Windows')
 
 """Commander Plugin for SSH Command
-   Dependencies: 
+   Dependencies: s
        pip3 install pexpect
 """
 
 def rotate(record, newpassword):
     """ Grab any required fields from the record """
+
     user = record.login
     oldpassword = record.password
 
@@ -29,12 +36,15 @@ def rotate(record, newpassword):
 
     try:
         s = pxssh.pxssh()
-        s.login(host, user, oldpassword)
+        s.login(host, user, oldpassword, sync_multiplier=3)
         s.sendline('passwd')
-        i = s.expect(['[Oo]ld [Pp]assword', 'current.*password', '[Nn]ew [Pp]assword'])
+        i = s.expect(['[Oo]ld.*[Pp]assword', '[Cc]urrent.*[Pp]assword', '[Nn]ew.*[Pp]assword'])
         if i == 0 or i == 1:
             s.sendline(oldpassword)
-            s.expect('[Nn]ew.*[Pp]assword')
+            i = s.expect(['[Nn]ew.*[Pp]assword', 'password unchanged'])
+            if i != 0:
+                return False
+
         s.sendline(newpassword)
         s.expect("Retype [Nn]ew.*[Pp]assword:")
         s.sendline(newpassword)
@@ -43,17 +53,16 @@ def rotate(record, newpassword):
         pass_result = s.before
 
         if "success" in str(pass_result):
-            print('Password changed successfully')
+            logging.info("Password changed successfully")
             record.password = newpassword
             result = True
         else:
-            print('Password change failed:')
-            print(pass_result)
+            logging.error("Password change failed: ", pass_result)
 
         s.logout()
     except exceptions.TIMEOUT as t:
-        print("Timed out waiting for response.")
+        logging.error("Timed out waiting for response.")
     except pxssh.ExceptionPxssh as e:
-        print("Failed to login with ssh.")
+        logging.error("Failed to login with ssh.")
 
     return result
